@@ -88,10 +88,10 @@ class AccessoryInterface(i2c.I2CBusMaster):
             reference to the connected spm COM class
 
         """
-        super().__init__(spm_ctrl=spm, bus_id=i2c.I2CBusID.Undef, 
-            instance_id=i2c.I2CBusMaster.I2CInstances.MAIN_APP, 
-            master_type=i2c.I2CBusMaster.I2CMasterType.ACCESSORY_MASTER, 
-            bus_speed=i2c.I2CBusMaster.I2CBusSpeed.kHz_200)
+        super().__init__(spm_ctrl=spm, bus_id=i2c.I2CBusID.Unassigned, 
+            instance_id=i2c.I2CInstances.MAIN_APP, 
+            master_type=i2c.I2CMasterType.ACCESSORY_MASTER, 
+            bus_speed=i2c.I2CBusSpeed.kHz_200)
         self._own_id_header = AISlaveIDHeader()
         self._active_port = -1
 
