@@ -5,7 +5,7 @@ class Chip_PCA9534(i2c.I2CChip):
     """ 8bit GPIO chip"""
 
     def __init__(self, bus_addr: int, **kwargs):
-        super().__init__(bus_addr, self.I2COffsetMode.NoOffset, **kwargs)
+        super().__init__(bus_addr, i2c.I2COffsetMode.NoOffset, **kwargs)
 
     @property
     def reg_config(self):
