@@ -392,8 +392,8 @@ class MotorControl:
         motor_moving = True
         time_out_reached = False
         start_time = time.time()
-        while motor_moving and not time_out_reached: 
-
+        already_checked_once = False
+        while motor_moving and not time_out_reached and not already_checked_once: 
             stopped = [] # list of stop state for each motor
             for index, motor in enumerate(motors):
                 status = self.get_motor_status(motor)
@@ -402,9 +402,12 @@ class MotorControl:
                 else:
                     stopped.append(False)
 
-            if all(stopped):
+            if all(stopped) and already_checked_once:
                 motor_moving = False
                 self.logger.debug("All motor stopped")
+            elif(all(stopped) and not already_checked_once):
+                already_checked_once = True # We check once more
+                self.logger.debug("Check again whether motors stopped")
             else:
                 if (time.time() - start_time) > self.max_wait_time:
                     time_out_reached = True
